/*!
 * jQuery Peelback
 * Copyright 2011, Rob Flaherty
 *
 * Dual licensed under the MIT and GPL licenses
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.gnu.org/licenses/gpl.html
 *
 */

(function($) {
  $.Peelback = function(el, settings) {

    //Caching
    var base = this;
    base.$el = $(el);
    base.el = el;
    base.$el.data("Peelback", base);

    //Main stuff
    base.init = function() {

      //Vars
      var peelHTML, peelImage, peelMask, peelAnim,
		direction=[], cssObj=[{width:0,height:0},{width:'',height:''}];

      //Defaults, meet Settings
      base.settings = $.extend({},$.Peelback.defaultSettings, settings);

      //If ad image is missing, stop the show
      if (typeof(base.settings.adImage) !== 'string' || base.settings.adImage === '') {
        if ( base.settings.debug === true) {
          console.log('Ad image missing');
        }
        return;
      }

      //If peel image is missing, stop the show
      if (typeof(base.settings.peelImage) !== 'string' || base.settings.peelImage === '') {
        if ( base.settings.debug === true) {
          console.log('Peel effect image missing');
        }
        return;
      }

      //If click URL is missing, stop the show
      if (typeof(base.settings.clickURL) !== 'string' || base.settings.clickURL === '') {
        if ( base.settings.debug === true) {
          console.log('Click URL missing');
        }
        return;
      }

      //Assemble
      peelHTML = $('<div id="' + nnr_ppa_data.prefix + 'of"><div id="' + nnr_ppa_data.prefix + 'peelback"><div id="' + nnr_ppa_data.prefix + 'clipper"><a data-id="' + nnr_ppa_data.data_id + '" href="' + base.settings.clickURL + '" target="' + base.settings.clickTarget + '" ' + base.settings.clickRel + '><img id="' + nnr_ppa_data.prefix + 'ad-image" src="' + base.settings.adImage +'" border="0" /></a></div><svg id="' + nnr_ppa_data.prefix + 'peel-image" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" preserveAspectRatio="none" width="972" height="972" viewBox="0 0 972 972"><path d="M881-2C878.3 56.7 863.7 369.3 861 428 857.3 584.8 860.2 473.5 856.8 629.2 858.7 702 851.8 820 870 889 699.9 839.7 440.7 837 235 861 156 869.3 77 877.7-2 886 292.3 590 586.7 294 881-2Z" id="' + nnr_ppa_data.prefix + 'path" /><image xlink:href="' + base.settings.peelImage + '" width="881" height="972"/></svg></div></div>');

      //Insert
      base.$el.prepend(peelHTML);

	  // Initial animation
	  switch(nnr_ppa_data.position)
	  {	case '1':
			direction = ['left','top'];
			break;
		case '2':
			direction = ['right','top'];
			break;
		case '3':
			direction = ['left','bottom'];
			break;
		case '4':
			direction = ['right','bottom'];
			break;
	  }
	  cssObj[0][direction[0]]=0;
	  cssObj[0][direction[1]]=0;
	  cssObj[1][direction[0]]='';
	  cssObj[1][direction[1]]='';
	  
	  peelAnim = peelHTML.find('>div:first>*');
	  
	  peelAnim.css(cssObj[0]).delay(500).queue(
		function(next){$(this).css(cssObj[1]);next();}
	  );
	  
	  // Shake animation
	  function timedAnim(next)
	  {	peelAnim.delay(5e3).queue(
			function(next){$(this).css(cssObj[0]);next();}
		).delay(350).queue(
			function(next){$(this).css(cssObj[1]);next();}
		).eq(0).queue(timedAnim);
		
		if (next) next();
	  }
	  timedAnim();
	  
      //Hover behavior
      peelHTML.find('>div:first').hover(

        //Mouseover
        function() {
			// Clear animations
			peelAnim.stop(true).css(cssObj[1]);
			
			// Mobile fix
			$(this).stop(true).delay(200).queue(
				function(){$(this).parent().addClass(nnr_ppa_data.prefix + 'hovered');}
			);

          //If GA tracking enabled
          if (base.settings.gaTrack === true) {
            if (typeof(_gaq) != 'undefined') {
              _gaq.push(['_trackEvent', 'Ad_Interaction', 'Peelback', base.settings.gaLabel]);
            } else {
              if (base.settings.debug === true) {
                console.log('Google Analytics _gaq object undefined');
              }
            }
         }
        },

        //Mouseout
        function() {			
			// Mobile fix
			$(this).stop(true).delay(200).queue(
				function()
				{	$(this).parent().removeClass(nnr_ppa_data.prefix + 'hovered');
				}
			);
		}

		
		// iPad fix
      ).find('a').on('click',function()
		{ 	if( !$(this).is('.' + nnr_ppa_data.prefix + 'hovered a') ) return false;
		}
	  );
	  $('#' + nnr_ppa_data.prefix + 'of').on('click',function(){});

    };

    // Run initializer
    base.init();
  };

  $.Peelback.defaultSettings = {
    adImage     : null,
    peelImage   : null,
    clickURL    : null,
    gaTrack     : false,
    gaLabel     : 'default',
    autoAnimate : true,
    debug       : false
  };

  $.fn.peelback = function(settings) {
    return this.each(function() {
      (new $.Peelback(this, settings));
    });
  };

})(jQuery);